@@ -8,7 +8,7 @@
 #
 ###############################################################################
 #
-#   $Id: REST.pm 22 2006-09-25 02:14:52Z  $
+#   $Id: REST.pm 33 2006-10-11 08:45:42Z  $
 #
 #   Description:    This is the protocol-implementation class for making
 #                   requests via the REST interface. At present, this is the
@@ -27,6 +27,7 @@
 #                   Error
 #                   XML::LibXML
 #                   WebService::ISBNDB::Agent
+#                   WebService::ISBNDB::Iterator
 #
 #   Global Consts:  $VERSION
 #                   $BASEURL
@@ -46,7 +47,9 @@ use Class::Std;
 use Error;
 use XML::LibXML;
 
-$VERSION = "0.20";
+use WebService::ISBNDB::Iterator;
+
+$VERSION = "0.30";
 
 BEGIN
 {
@@ -202,9 +205,6 @@ sub request_uri : RESTRICTED
 #                   $obj      in      scalar    Object or type name or class
 #                   $args     in      hashref   Hash reference of arguments to
 #                                                 the raw request
-#                   $single   in      boolean   True/false whether we are to
-#                                                 return a singular or plural
-#                                                 result
 #
 #   Returns:        Success:    based on $single, a API-derived object or list
 #                   Failure:    throws Error::Simple
@@ -212,14 +212,9 @@ sub request_uri : RESTRICTED
 ###############################################################################
 sub request : RESTRICTED
 {
-    my ($self, $obj, $args, $single) = @_;
+    my ($self, $obj, $args) = @_;
     $obj = $self->resolve_obj($obj);
 
-    # Do we overwrite $obj with the new data, return it instead of a new
-    # object? We do this in "single" mode when $obj is an object instead of a
-    # type-name or full class-name.
-    my $overwrite = ($single and ref($obj)) ? 1 : 0;
-
     my $content = $self->raw_request($obj, $args);
 
     # First off, parse $content as XML
@@ -232,9 +227,11 @@ sub request : RESTRICTED
         if (($dom) = $top_elt->getElementsByTagName('ErrorMessage'));
     my ($value, $stats) = $parse_table{$obj->get_type}->($self, $top_elt);
 
-    $obj->copy(ref($value) ? $value->[0] : $value) if $overwrite;
+    # Add two pieces to $stats that the iterator will need
+    $stats->{contents} = $value;
+    $stats->{request_args} = $args;
 
-    $value;
+    WebService::ISBNDB::Iterator->new($stats);
 }
 
 ###############################################################################
@@ -443,10 +440,8 @@ sub parse_books : RESTRICTED
             $bookref->{price_time} = $tmp->getAttribute('price_time');
             if ($CAN_PARSE_DATES)
             {
-                $bookref->{change_time_sec} =
-                    str2time($bookref->{change_time}, 'UTC');
-                $bookref->{price_time_sec} =
-                    str2time($bookref->{price_time}, 'UTC');
+                $bookref->{change_time_sec} = str2time($bookref->{change_time});
+                $bookref->{price_time_sec} = str2time($bookref->{price_time});
             }
         }
         # Look for summary text
@@ -482,7 +477,7 @@ sub parse_books : RESTRICTED
                 if ($CAN_PARSE_DATES and $marcs->[$#$marcs]->{last_update})
                 {
                     $marcs->[$#$marcs]->{last_update_sec} =
-                        str2time($marcs->[$#$marcs]->{last_update}, 'UTC');
+                        str2time($marcs->[$#$marcs]->{last_update});
                 }
             }
             $bookref->{marc} = $marcs;
@@ -508,7 +503,7 @@ sub parse_books : RESTRICTED
                 if ($CAN_PARSE_DATES and $prices->[$#$prices]->{check_time})
                 {
                     $prices->[$#$prices]->{check_time_sec} =
-                        str2time($prices->[$#$prices]->{check_time}, 'UTC');
+                        str2time($prices->[$#$prices]->{check_time});
                 }
             }
             $bookref->{prices} = $prices;
@@ -810,13 +805,12 @@ Each of these returns a list-reference of objects, even when there is only
 one result value. All of these methods are restricted to this class and
 its decendants.
 
-=item request($OBJ, $ARGS, $SINGLE) (R)
+=item request($OBJ, $ARGS) (R)
 
 Use the B<LWP::UserAgent> object to make a request on the remote service.
 C<$OBJ> indicates what type of data request is being made, and C<$ARGS> is a
-hash-reference of arguments to be passed in the request. The value C<$SINGLE>
-is a boolean that indicates whether a single value should be returned, or all
-values that result from parsing.
+hash-reference of arguments to be passed in the request. The return value is
+an object of the B<WebService::ISBNDB::Iterator> class.
 
 This method is restricted to this class, and is the required overload of the
 request() method from the parent class (L<WebService::ISBNDB::Agent>).
@@ -866,7 +860,8 @@ implemented.
 
 =head1 SEE ALSO
 
-L<WebService::ISBNDB::Agent>, L<LWP::UserAgent>
+L<WebService::ISBNDB::Agent>, L<WebService::ISBNDB::Iterator>,
+L<LWP::UserAgent>
 
 =head1 AUTHOR
 
